@@ -2,12 +2,12 @@ package Test::Builder::Module;
 
 use strict;
 
-use Test::Builder 1.00;
+use Test::Builder 0.99;
 
 require Exporter;
 our @ISA = qw(Exporter);
 
-our $VERSION = '1.302014_010';
+our $VERSION = '1.001007';
 $VERSION = eval $VERSION;      ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -22,7 +22,7 @@ Test::Builder::Module - Base class for test modules
 
   my $CLASS = __PACKAGE__;
 
-  use parent 'Test::Builder::Module';
+  use base 'Test::Builder::Module';
   @EXPORT = qw(ok);
 
   sub ok ($;$) {
