@@ -17,7 +17,7 @@ sub _carp {
     return warn @_, " at $file line $line\n";
 }
 
-our $VERSION = '1.302014_010';
+our $VERSION = '1.001007';
 $VERSION = eval $VERSION;    ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 use Test::Builder::Module 0.99;
@@ -1293,13 +1293,10 @@ sub skip {
     my( $why, $how_many ) = @_;
     my $tb = Test::More->builder;
 
-    # If the plan is set, and is static, then skip needs a count. If the plan
-    # is 'no_plan' we are fine. As well if plan is undefined then we are
-    # waiting for done_testing.
-    unless (defined $how_many) {
-        my $plan = $tb->has_plan;
+    unless( defined $how_many ) {
+        # $how_many can only be avoided when no_plan is in use.
         _carp "skip() needs to know \$how_many tests are in the block"
-            if $plan && $plan =~ m/^\d+$/;
+          unless $tb->has_plan eq 'no_plan';
         $how_many = 1;
     }
 
@@ -1906,6 +1903,8 @@ comes from.
 
 =head2 BUNDLES
 
+L<Bundle::Test> installs a whole bunch of useful test modules.
+
 L<Test::Most> Most commonly needed test functions and features.
 
 =head1 AUTHORS
